@@ -17,7 +17,7 @@ if(model_type == "mostly fixed"){
   estParNames <- c(sharedParNames,unitParNames)
   fixedParNames <- setdiff(parNames,estParNames)
 } else if(model_type == "plausible parameters shared"){
-  # parameters are shared when that makes mechanistic sense. 
+  # parameters are shared when that makes mechanistic sense.
   sharedParNames <- c("R0","g","sigma","gamma","amplitude")
   unitParNames <- c("sigmaSE","S_0","E_0","I_0","rho","psi")
   estParNames <- c(sharedParNames,unitParNames)
@@ -34,7 +34,7 @@ if(model_type == "mostly fixed"){
   fixedParNames <- c("mu","g")
   sharedParNames <- NULL
   unitParNames <- setdiff(parNames,fixedParNames)
-  estParNames <- c(sharedParNames,unitParNames)  
+  estParNames <- c(sharedParNames,unitParNames)
 }
 
 # Note: here we assume that there are no unestimated unit-specific
@@ -63,7 +63,7 @@ fixedParNames_expanded <- paste0(fixedParNames,1)
 reg_rw.sd <- rep(list(0.02),times=length(regEstParNames_expanded))
 names(reg_rw.sd) <- regEstParNames_expanded
 if("alpha"%in%estParNames) reg_rw.sd[paste0("alpha",1:h_U)] <- 0.005
- 
+
 ivp_rw.sd <- lapply(ivpEstParNames_expanded,function(x)expression(ivp(0.05)))
 names(ivp_rw.sd) <- ivpEstParNames_expanded
 h_rw.sd <- do.call(rw_sd,c(reg_rw.sd,ivp_rw.sd))
@@ -89,6 +89,26 @@ paste("ibpf logLik for he10 model:",logLik(bpfilter(h_ibpf,Np=10,block_size=1)))
 
 coef(h_ibpf)
 
+## test error message when munit_measure is undefined
+try(girf(h_model,kind="moment",
+  Np=10,Ninter=2,Nguide=10,lookahead=1,tol=1e-5))
 
+# Create second ibpfd_spatPomp object with different chain length, to test error
+h_ibpf2 <- ibpf(h_model,
+                params=coef(h_model),
+                sharedParNames=sharedParNames,
+                unitParNames=unitParNames,
+                Nbpf=3,
+                spat_regression=0.1,
+                Np=10,
+                rw.sd=h_rw.sd,
+                cooling.fraction.50=0.5,
+                block_list=block_list
+)
 
+# Should correctly make ibpfList object
+is(c(h_ibpf, h_ibpf), "ibpfList")
+
+# Throws error because they have different chain lengths
+try(c(h_ibpf, h_ibpf2))
 
